/*
marks.c
Author: Hayden Walles
Date: 18 September 2007
Implementation of the SEAM_MARKS interface.
*/

/*
    Copyright (C) 2007 Hayden Walles

    This file is part of Seamstress.

    Seamstress is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Seamstress is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "seams.h"

SEAM_MARKS *seamstressNewMarks(int width, int height,int *error){
  SEAM_MARKS *new;
  int i,j;

  new=newMatrix(height,width,MT_BYTE,error);

  if(new==NULL)
    return NULL;

  for(i=0;i<height;i++){
    for(j=0;j<width;j++)
      setByte(new,i,j,0);
  }

  return new;
}

/*Makes some manual marks in a rectangle.  Type==1 for protective, 2 for destructive, 0 to cancel previous marks.  May return zero if the marks matrix doesn't exist yet, and there isn't enough memory to do so.*/
int marksAnnotate(SEAM_MARKS *marks, int l, int t, int r, int b,int type){
  int i,j;

  if(marks==NULL){
    marks=newMatrix(matrixRows(marks),matrixCols(marks),MT_BYTE,NULL);
    /*Should be handling error stuff here.*/
    if(marks==NULL)
      return 0;
    for(i=0;i<matrixRows(marks);i++){
      for(j=0;j<matrixCols(marks);j++)
	setByte(marks,i,j,0);
    }
  }

  if(l<0)
    l=0;
  if(r>matrixCols(marks)-1)
    r=matrixCols(marks)-1;
  if(t<0)
    t=0;
  if(b>matrixRows(marks)-1)
    b=matrixRows(marks)-1;
  
  for(i=t;i<=b;i++){
    for(j=l;j<=r;j++)
      setByte(marks,i,j,type);
  }

  return 1;

}


void marksDelete(SEAM_MARKS *marks){
  free(marks);
}

